@@ -41,23 +41,25 @@ xmalloc (size_t nb)
 	/*
 	 *	a (skewed) fgets() that works on file descriptors
 	 *	the '\r' charecter is ignored
+	 *	returns the number of bytes written into the given
+	 *	 buffer, including the terminating NUL
 	 */
 static int
-_getl (int d, char *p, u_short l)
+_getl (int d, char *begin, u_short len)
 {
-	size_t n = 0;
+	char *p, *end;
 
-	while (read (d, p, 1) == 1) {
+	end = &begin[len-1]; /* leave room for terminating NUL */
+	for (p = begin; p < end; ++p) {
+		if (read (d, p, 1) != 1)
+			break;
 		if (*p == '\n')
 			break;
 		if (*p == '\r')
 			p--;	/* ignore \r */
-		p++;
-		if (n++ >= l)
-			break;
 	}
-	*p = 0;
-	return n;
+	*p++ = 0;
+	return p-begin;
 }
 
 	/*
